# Connectors
A simple, lightweight set of connectors and functions to various APIs, controlled by a central broker.

## How to install
1. Install via pip to your environment: `pip install ppp-connectors`
2. Load the required environment variables into your environment. You can find these in `env.sample`. This library is intelligent enough to look for both a `.env` file or within your system's environment variables.